#include "fftorder.h"

const unsigned char fftorder_256[] = {
0,128,64,192,32,160,224,96,16,144,80,208,240,112,48,176,
8,136,72,200,40,168,232,104,248,120,56,184,24,152,216,88,
4,132,68,196,36,164,228,100,20,148,84,212,244,116,52,180,
252,124,60,188,28,156,220,92,12,140,76,204,236,108,44,172,
2,130,66,194,34,162,226,98,18,146,82,210,242,114,50,178,
10,138,74,202,42,170,234,106,250,122,58,186,26,154,218,90,
254,126,62,190,30,158,222,94,14,142,78,206,238,110,46,174,
6,134,70,198,38,166,230,102,246,118,54,182,22,150,214,86,
1,129,65,193,33,161,225,97,17,145,81,209,241,113,49,177,
9,137,73,201,41,169,233,105,249,121,57,185,25,153,217,89,
5,133,69,197,37,165,229,101,21,149,85,213,245,117,53,181,
253,125,61,189,29,157,221,93,13,141,77,205,237,109,45,173,
255,127,63,191,31,159,223,95,15,143,79,207,239,111,47,175,
7,135,71,199,39,167,231,103,247,119,55,183,23,151,215,87,
3,131,67,195,35,163,227,99,19,147,83,211,243,115,51,179,
251,123,59,187,27,155,219,91,11,139,75,203,235,107,43,171
} ;
